Learn R Programming

rayvertex (version 0.15.0)

add_sphere_uv_mesh: Add Sphere UV Mapping to Mesh

Description

Applies a planar UV mapping to a mesh based on a spherical direction from the origin.

Usage

add_sphere_uv_mesh(mesh, origin = c(0, 0, 0), override_existing = FALSE)

Value

Modified mesh with added UV mapping.

Arguments

mesh

The mesh to which the UV mapping will be applied.

origin

Default c(0, 0, 0). A vector specifying the origin to apply spherical UV coordinates.

override_existing

Default FALSE. Specifies whether existing UV coordinates should be overridden.

Examples

Run this code
if (FALSE) { # interactive() || isTRUE(as.logical(Sys.getenv("IN_PKGDOWN")))
#Let's construct a mesh from the volcano dataset
}

Run the code above in your browser using DataLab