powered by
Applies a planar UV mapping to a mesh based on a spherical direction from the origin.
add_sphere_uv_mesh(mesh, origin = c(0, 0, 0), override_existing = FALSE)
Modified mesh with added UV mapping.
The mesh to which the UV mapping will be applied.
Default c(0, 0, 0). A vector specifying the origin to apply spherical UV coordinates.
c(0, 0, 0)
Default FALSE. Specifies whether existing UV coordinates should be overridden.
FALSE
if (FALSE) { # interactive() || isTRUE(as.logical(Sys.getenv("IN_PKGDOWN"))) #Let's construct a mesh from the volcano dataset }
Run the code above in your browser using DataLab